@@ -19,8 +19,6 @@
 
 #include "KReportUtils.h"
 #include "KReportUnit.h"
-#include "KReportPosition.h"
-#include "KReportSize.h"
 #include "KReportItemBase.h"
 #include "KReportLineStyle.h"
 
@@ -31,29 +29,29 @@
 
 #include <float.h>
 
-QString KReportUtils::attr(const QDomElement &el, const char *attrName,
+QString KReportUtils::attr(const QDomElement &el, const QString &attrName,
                            const QString &defaultValue)
 {
-    const QString val = el.attribute(QLatin1String(attrName));
+    const QString val = el.attribute(attrName);
     return val.isEmpty() ? defaultValue : val;
 }
 
-QByteArray KReportUtils::attr(const QDomElement &el, const char *attrName,
+QByteArray KReportUtils::attr(const QDomElement &el, const QString &attrName,
                            const QByteArray &defaultValue)
 {
-    const QByteArray val = el.attribute(QLatin1String(attrName)).toLatin1();
+    const QByteArray val = el.attribute(attrName).toLatin1();
     return val.isEmpty() ? defaultValue : val;
 }
 
-bool KReportUtils::attr(const QDomElement &el, const char *attrName, bool defaultValue)
+bool KReportUtils::attr(const QDomElement &el, const QString &attrName, bool defaultValue)
 {
-    const QString val = el.attribute(QLatin1String(attrName));
+    const QString val = el.attribute(attrName);
     return val.isEmpty() ? defaultValue : QVariant(val).toBool();
 }
 
-int KReportUtils::attr(const QDomElement &el, const char *attrName, int defaultValue)
+int KReportUtils::attr(const QDomElement &el, const QString &attrName, int defaultValue)
 {
-    const QString val = el.attribute(QLatin1String(attrName));
+    const QString val = el.attribute(attrName);
     if (val.isEmpty()) {
         return defaultValue;
     }
@@ -62,24 +60,24 @@ int KReportUtils::attr(const QDomElement &el, const char *attrName, int defaultV
     return ok ? result : defaultValue;
 }
 
-qreal KReportUtils::attr(const QDomElement &el, const char *attrName, qreal defaultValue)
+qreal KReportUtils::attr(const QDomElement &el, const QString &attrName, qreal defaultValue)
 {
-    const QString val = el.attribute(QLatin1String(attrName));
+    const QString val = el.attribute(attrName);
     return KReportUnit::parseValue(val, defaultValue);
 }
 
-QColor KReportUtils::attr(const QDomElement &el, const char *attrName, const QColor &defaultValue)
+QColor KReportUtils::attr(const QDomElement &el, const QString &attrName, const QColor &defaultValue)
 {
-    const QString val = el.attribute(QLatin1String(attrName));
+    const QString val = el.attribute(attrName);
     if (val.isEmpty()) {
         return defaultValue;
     }
     return QColor(val);
 }
 
-qreal KReportUtils::attrPercent(const QDomElement& el, const char* attrName, qreal defaultValue)
+qreal KReportUtils::attrPercent(const QDomElement& el, const QString &attrName, qreal defaultValue)
 {
-    QString str(el.attribute(QLatin1String(attrName)));
+    QString str(el.attribute(attrName));
     if (str.isEmpty() || !str.endsWith(QLatin1Char('%'))) {
         return defaultValue;
     }
@@ -164,20 +162,42 @@ QString KReportUtils::horizontalToString(Qt::Alignment alignment)
     return QString();
 }
 
-QRectF KReportUtils::readRectAttributes(const QDomElement &el, const QRectF &defaultValue)
+QString KReportUtils::readNameAttribute(const QDomElement &el, const QString &defaultValue)
 {
-    QRectF val;
-    val.setX(attr(el, "svg:x", defaultValue.x()));
-    val.setY(attr(el, "svg:y", defaultValue.y()));
-    val.setWidth(attr(el, "svg:width", defaultValue.width()));
-    val.setHeight(attr(el, "svg:height", defaultValue.height()));
+    return attr(el, QLatin1String("report:name"), defaultValue);
+}
+
+QSizeF KReportUtils::readSizeAttributes(const QDomElement &el, const QSizeF &defaultValue)
+{
+    QSizeF val;
+    val.setWidth(attr(el, QLatin1String("svg:width"), defaultValue.width()));
+    if (val.width() < 0.0) {
+        val.setWidth(defaultValue.width());
+    }
+    val.setHeight(attr(el, QLatin1String("svg:height"), defaultValue.height()));
+    if (val.height() < 0.0) {
+        val.setHeight(defaultValue.height());
+    }
     return val;
 }
 
-int KReportUtils::readPercent(const QDomElement& el, const char* name, int defaultPercentValue, bool *ok)
+QRectF KReportUtils::readRectAttributes(const QDomElement &el, const QRectF &defaultValue)
 {
-    Q_ASSERT(name);
-    QString percent(el.attribute(QLatin1String(name)));
+    QRectF val;
+    val.setX(attr(el, QLatin1String("svg:x"), defaultValue.x()));
+    val.setY(attr(el, QLatin1String("svg:y"), defaultValue.y()));
+    val.setSize(readSizeAttributes(el, defaultValue.size()));
+    return val;
+}
+
+qreal KReportUtils::readZAttribute(const QDomElement &el, qreal defaultValue)
+{
+    return KReportUtils::attr(el, QLatin1String("report:z-index"), defaultValue);
+}
+
+int KReportUtils::readPercent(const QDomElement& el, const QString &attrName, int defaultPercentValue, bool *ok)
+{
+    QString percent(el.attribute(attrName));
     if (percent.isEmpty()) {
         if (ok)
             *ok = true;
@@ -194,6 +214,11 @@ int KReportUtils::readPercent(const QDomElement& el, const char* name, int defau
     return percent.toInt(ok);
 }
 
+QString KReportUtils::readSectionTypeNameAttribute(const QDomElement &el, const QString &defaultValue)
+{
+    return attr(el, QLatin1String("report:section-type"), defaultValue);
+}
+
 //! @return string representation of @a value, cuts of zeros; precision is set to 2
 static QString roundValueToString(qreal value)
 {
@@ -222,11 +247,12 @@ void KReportUtils::readFontAttributes(const QDomElement& el, QFont *font)
 {
     Q_ASSERT(font);
     const QFont::Capitalization cap = readFontCapitalization(
-        attr(el, "fo:font-variant", QByteArray()), attr(el, "fo:text-transform", QByteArray()));
+        attr(el, QLatin1String("fo:font-variant"), QByteArray()),
+        attr(el, QLatin1String("fo:text-transform"), QByteArray()));
     font->setCapitalization(cap);
 
     // weight
-    const QByteArray fontWeight(attr(el, "fo:font-weight", QByteArray()));
+    const QByteArray fontWeight(attr(el, QLatin1String("fo:font-weight"), QByteArray()));
     int weight = -1;
     if (fontWeight == "bold") {
         weight = QFont::Bold;
@@ -250,27 +276,31 @@ void KReportUtils::readFontAttributes(const QDomElement& el, QFont *font)
         font->setWeight(weight);
     }
 
-    font->setItalic(attr(el, "fo:font-style", QByteArray()) == "italic");
-    font->setFixedPitch(attr(el, "style:font-pitch", QByteArray()) == "fixed");
-    font->setFamily(attr(el, "fo:font-family", font->family()));
-    font->setKerning(attr(el, "style:letter-kerning", font->kerning()));
+    font->setItalic(attr(el, QLatin1String("fo:font-style"), QByteArray()) == "italic");
+    font->setFixedPitch(attr(el, QLatin1String("style:font-pitch"), QByteArray()) == "fixed");
+    font->setFamily(attr(el, QLatin1String("fo:font-family"), font->family()));
+    font->setKerning(attr(el, QLatin1String("style:letter-kerning"), font->kerning()));
 
     // underline
-    const QByteArray underlineType(attr(el, "style:text-underline-type", QByteArray()));
-    font->setUnderline(!underlineType.isEmpty() && underlineType != "none"); // double or single (we don't recognize them)
+    const QByteArray underlineType(
+        attr(el, QLatin1String("style:text-underline-type"), QByteArray()));
+    font->setUnderline(!underlineType.isEmpty()
+                       && underlineType
+                           != "none"); // double or single (we don't recognize them)
 
     // stricken-out
-    const QByteArray strikeOutType(attr(el, "style:text-line-through-type", QByteArray()));
+    const QByteArray strikeOutType(attr(el, QLatin1String("style:text-line-through-type"), QByteArray()));
     font->setStrikeOut(!strikeOutType.isEmpty() && strikeOutType != "none"); // double or single (we don't recognize them)
 
 //! @todo support fo:font-size-rel?
 //! @todo support fo:font-size in px
-    font->setPointSizeF(KReportUtils::attr(el, "fo:font-size", font->pointSizeF()));
+    font->setPointSizeF(KReportUtils::attr(el, QLatin1String("fo:font-size"), font->pointSizeF()));
 
     // letter spacing
     // §7.16.2 of [XSL] http://www.w3.org/TR/xsl11/#letter-spacing
     font->setLetterSpacing(QFont::PercentageSpacing,
-                          100.0 * KReportUtils::attrPercent(el, "fo:letter-spacing", font->letterSpacing()));
+        100.0 * KReportUtils::attrPercent(
+                    el, QLatin1String("fo:letter-spacing"), font->letterSpacing()));
 }
 
 void KReportUtils::writeFontAttributes(QDomElement *el, const QFont &font)
@@ -328,7 +358,8 @@ void KReportUtils::writeFontAttributes(QDomElement *el, const QFont &font)
         el->setAttribute(QLatin1String("fo:font-family"), font.family());
     }
     // kerning, default is "true"
-    el->setAttribute(QLatin1String("style:letter-kerning"), QLatin1String(font.kerning() ? "true" : "false"));
+    el->setAttribute(QLatin1String("style:letter-kerning"),
+        font.kerning() ? QLatin1String("true") : QLatin1String("false"));
     // underline, default is "none"
     if (font.underline()) {
         el->setAttribute(QLatin1String("style:text-underline-type"), QLatin1String("single"));
@@ -356,16 +387,15 @@ void KReportUtils::writeFontAttributes(QDomElement *el, const QFont &font)
 }
 
 
-void KReportUtils::buildXMLRect(QDomElement *entity, KReportPosition *pos, KReportSize *size)
+void KReportUtils::buildXMLRect(QDomElement *entity, const QPointF &pos, const QSizeF &size)
 {
     Q_ASSERT(entity);
-    Q_ASSERT(pos);
-    Q_ASSERT(size);
-    KReportUtils::setAttribute(entity, pos->toPoint() );
-    KReportUtils::setAttribute(entity, size->toPoint() );
+
+    KReportUtils::setAttribute(entity, pos);
+    KReportUtils::setAttribute(entity, size );
 }
 
-void KReportUtils::buildXMLTextStyle(QDomDocument *doc, QDomElement *entity, const KRTextStyleData &ts)
+void KReportUtils::buildXMLTextStyle(QDomDocument *doc, QDomElement *entity, const KReportTextStyleData &ts)
 {
     Q_ASSERT(doc);
     Q_ASSERT(entity);
@@ -386,7 +416,7 @@ void KReportUtils::buildXMLLineStyle(QDomDocument *doc, QDomElement *entity, con
     QDomElement element = doc->createElement(QLatin1String("report:line-style"));
 
     element.setAttribute(QLatin1String("report:line-color"), ls.color().name());
-    element.setAttribute(QLatin1String("report:line-weight"), ls.width());
+    element.setAttribute(QLatin1String("report:line-weight"), ls.weight());
 
     QString l;
     switch (ls.penStyle()) {
@@ -420,7 +450,7 @@ void KReportUtils::addPropertyAsAttribute(QDomElement* e, KProperty* p)
 {
     Q_ASSERT(e);
     Q_ASSERT(p);
-    const QString name = QLatin1String("report:") + QLatin1String(p->name().toLower());
+    const QString name = QLatin1String("report:") + QString::fromLatin1(p->name().toLower());
 
     switch (p->value().type()) {
         case QVariant::Int :
@@ -460,16 +490,19 @@ void KReportUtils::setAttribute(QDomElement *e, const QSizeF &value)
     KReportUtils::setAttribute(e, QLatin1String("svg:height"), value.height());
 }
 
-bool KReportUtils::parseReportTextStyleData(const QDomElement & elemSource, KRTextStyleData *ts)
+bool KReportUtils::parseReportTextStyleData(const QDomElement & elemSource, KReportTextStyleData *ts)
 {
     Q_ASSERT(ts);
     if (elemSource.tagName() != QLatin1String("report:text-style"))
         return false;
-    ts->backgroundColor = QColor(elemSource.attribute(QLatin1String("fo:background-color"), QLatin1String("#ffffff")));
-    ts->foregroundColor = QColor(elemSource.attribute(QLatin1String("fo:foreground-color"), QLatin1String("#000000")));
+    ts->backgroundColor = QColor(elemSource.attribute(
+        QLatin1String("fo:background-color"), QLatin1String("#ffffff")));
+    ts->foregroundColor = QColor(elemSource.attribute(
+        QLatin1String("fo:foreground-color"), QLatin1String("#000000")));
 
     bool ok;
-    ts->backgroundOpacity = KReportUtils::readPercent(elemSource, "fo:background-opacity", 100, &ok);
+    ts->backgroundOpacity = KReportUtils::readPercent(
+        elemSource, QLatin1String("fo:background-opacity"), 100, &ok);
     if (!ok) {
         return false;
     }
@@ -482,7 +515,7 @@ bool KReportUtils::parseReportLineStyleData(const QDomElement & elemSource, KRep
     Q_ASSERT(ls);
     if (elemSource.tagName() == QLatin1String("report:line-style")) {
         ls->setColor(QColor(elemSource.attribute(QLatin1String("report:line-color"), QLatin1String("#ffffff"))));
-        ls->setWidth(elemSource.attribute(QLatin1String("report:line-weight"), QLatin1String("0.0")).toDouble());
+        ls->setWeight(elemSource.attribute(QLatin1String("report:line-weight"), QLatin1String("0.0")).toDouble());
 
         QString l = elemSource.attribute(QLatin1String("report:line-style"), QLatin1String("nopen"));
         if (l == QLatin1String("nopen")) {
@@ -503,28 +536,6 @@ bool KReportUtils::parseReportLineStyleData(const QDomElement & elemSource, KRep
     return false;
 }
 
-bool KReportUtils::parseReportRect(const QDomElement & elemSource, KReportPosition *pos, KReportSize *size)
-{
-    Q_ASSERT(pos);
-    Q_ASSERT(size);
-//    QStringList sl;
-//    QDomNamedNodeMap map = elemSource.attributes();
-//    for (int i=0; i < map.count(); ++i ) {
-//        sl << map.item(i).nodeName();
-//    }
-    QPointF _pos;
-    QSizeF _siz;
-
-    _pos.setX(KReportUnit::parseValue(elemSource.attribute(QLatin1String("svg:x"), QLatin1String("1cm"))));
-    _pos.setY(KReportUnit::parseValue(elemSource.attribute(QLatin1String("svg:y"), QLatin1String("1cm"))));
-    _siz.setWidth(KReportUnit::parseValue(elemSource.attribute(QLatin1String("svg:width"), QLatin1String("1cm"))));
-    _siz.setHeight(KReportUnit::parseValue(elemSource.attribute(QLatin1String("svg:height"), QLatin1String("1cm"))));
-
-    pos->setPointPos(_pos);
-    size->setPointSize(_siz);
-    return true;
-}
-
 class PageIds : private QHash<QString, QPageSize::PageSizeId>
 {
 public:
