@@ -33,9 +33,9 @@ public:
 
     ~KReportLabelPlugin() override;
 
-    QObject *createRendererInstance(const QDomNode &elem) override;
+    QObject *createRendererInstance(const QDomNode &) override;
     QObject *createDesignerInstance(KReportDesigner *designer, QGraphicsScene *scene,
-                                    const QPointF &pos) override;
+                                    const QPointF &) override;
     QObject *createDesignerInstance(const QDomNode &element, KReportDesigner *designer,
                                     QGraphicsScene *scene) override;
     KReportElement createElement() override;
