@@ -16,33 +16,30 @@
  * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "KReportItemMaps.h"
+#include "KReportUtils.h"
+#include "KReportRenderObjects.h"
 
+#include <KPropertyListData>
 #include <KPropertySet>
 
 #include <QStringList>
 
-#include <KReportRenderObjects.h>
-
 #include <sys/socket.h>
 
 #define myDebug() if (0) kDebug(44021)
 
-KReportItemMaps::KReportItemMaps(const QDomNode &element)
-    : m_longtitude(0)
-    , m_latitude(0)
-    , m_zoom(1200)
-    , m_pageId(0)
-    , m_sectionId(0)
-    , m_oroPicture(0)
-    , m_longDataSetFromScript(false)
-    , m_latDataSetFromScript(false)
-    , m_zoomDataSetFromScript(false)
+//! @todo replace with ReportItemMaps(const QDomNode &element = QDomNode())
+KReportItemMaps::KReportItemMaps()
 {
     createProperties();
+}
 
-    m_name->setValue(element.toElement().attribute(QLatin1String("report:name")));
-    m_controlSource->setValue(element.toElement().attribute(QLatin1String("report:item-data-source")));
-    Z = element.toElement().attribute(QLatin1String("report:z-index")).toDouble();
+KReportItemMaps::KReportItemMaps(const QDomNode &element)
+    : KReportItemMaps()
+{
+    nameProperty()->setValue(KReportUtils::readNameAttribute(element.toElement()));
+    setItemDataSource(element.toElement().attribute(QLatin1String("report:item-data-source")));
+    setZ(element.toElement().attribute(QLatin1String("report:z-index")).toDouble());
     m_latitudeProperty->setValue(element.toElement().attribute(QLatin1String("report:latitude")).toDouble());
     m_longitudeProperty->setValue(element.toElement().attribute(QLatin1String("report:longitude")).toDouble());
     m_zoomProperty->setValue(element.toElement().attribute(QLatin1String("report:zoom")).toInt());
@@ -50,65 +47,49 @@ KReportItemMaps::KReportItemMaps(const QDomNode &element)
     themeId = themeId.isEmpty() ? m_themeManager.mapThemeIds()[0] : themeId;
     m_themeProperty->setValue(themeId);
 
-    parseReportRect(element.toElement(), &m_pos, &m_size);
+    parseReportRect(element.toElement());
 }
 
 KReportItemMaps::~KReportItemMaps()
 {
-    delete m_set;
 }
 
 void KReportItemMaps::createProperties()
 {
-    m_set = new KPropertySet;
+    createDataSourceProperty();
 
-    m_controlSource = new KProperty("item-data-source", QStringList(), QStringList(), QString(), tr("Data Source"));
-
-    m_latitudeProperty = new KProperty("latitude", 0.0, tr("Latitude"), tr("Latitude"), KProperty::Double);
+    m_latitudeProperty = new KProperty("latitude", 0.0, tr("Latitude"), QString(), KProperty::Double);
     m_latitudeProperty->setOption("min", -90);
     m_latitudeProperty->setOption("max", 90);
-    m_latitudeProperty->setOption("unit", QString::fromUtf8("°"));
+    m_latitudeProperty->setOption("suffix", QString::fromUtf8("°"));
     m_latitudeProperty->setOption("precision", 7);
 
-    m_longitudeProperty = new KProperty("longitude", 0.0, tr("Longitude"), tr("Longitude"), KProperty::Double);
+    m_longitudeProperty = new KProperty("longitude", 0.0, tr("Longitude"), QString(), KProperty::Double);
     m_longitudeProperty->setOption("min", -180);
     m_longitudeProperty->setOption("max", 180);
-    m_longitudeProperty->setOption("unit", QString::fromUtf8("°"));
+    m_longitudeProperty->setOption("suffix", QString::fromUtf8("°"));
     m_longitudeProperty->setOption("precision", 7);
 
-    m_zoomProperty     = new KProperty("zoom", 1000, tr("Zoom"), tr("Zoom") );
+    m_zoomProperty     = new KProperty("zoom", 1000, tr("Zoom") );
     m_zoomProperty->setOption("min", 0);
     m_zoomProperty->setOption("max", 4000);
     m_zoomProperty->setOption("step", 100);
     m_zoomProperty->setOption("slider", true);
 
     QStringList mapThemIds(m_themeManager.mapThemeIds());
-    m_themeProperty = new KProperty("theme",
-                                                    mapThemIds,
-                                                    mapThemIds,
-                                                    mapThemIds[1]);
+
+    m_themeProperty = new KProperty("theme", new KPropertyListData(mapThemIds, mapThemIds),
+                                    QVariant(mapThemIds[1]), tr("Theme"));
 
     if (mapThemIds.contains(QLatin1String("earth/srtm/srtm.dgml"))) {
-        m_themeProperty->setValue(QLatin1String("earth/srtm/srtm.dgml"), false);
+        m_themeProperty->setValue(QLatin1String("earth/srtm/srtm.dgml"),
+                                  KProperty::ValueOption::IgnoreOld);
     }
 
-    addDefaultProperties();
-    m_set->addProperty(m_controlSource);
-    m_set->addProperty(m_latitudeProperty);
-    m_set->addProperty(m_longitudeProperty);
-    m_set->addProperty(m_zoomProperty);
-    m_set->addProperty(m_themeProperty);
-}
-
-
-void KReportItemMaps::setColumn(const QString &c)
-{
-    m_controlSource->setValue(c);
-}
-
-QString KReportItemMaps::itemDataSource() const
-{
-    return m_controlSource->value().toString();
+    propertySet()->addProperty(m_latitudeProperty);
+    propertySet()->addProperty(m_longitudeProperty);
+    propertySet()->addProperty(m_zoomProperty);
+    propertySet()->addProperty(m_themeProperty);
 }
 
 QString KReportItemMaps::typeName() const
@@ -128,16 +109,18 @@ int KReportItemMaps::renderSimpleData(OROPage *page, OROSection *section, const
 
 
     m_oroPicture = new OROPicture();
-    m_oroPicture->setPosition(m_pos.toScene() + m_offset);
-    m_oroPicture->setSize(m_size.toScene());
+    m_oroPicture->setPosition(scenePosition(position()) + m_offset);
+    m_oroPicture->setSize(sceneSize(size()));
 
     if (m_pageId) {
-        m_pageId->addPrimitive(m_oroPicture);
+        m_pageId->insertPrimitive(m_oroPicture);
     }
 
     if (m_sectionId) {
         OROPicture *i2 = dynamic_cast<OROPicture*>(m_oroPicture->clone());
-        i2->setPosition(m_pos.toPoint());
+        if (i2) {
+            i2->setPosition(scenePosition(position()));
+        }
     }
 
     m_mapRenderer.renderJob(this);
@@ -185,11 +168,6 @@ int KReportItemMaps::zoom() const
     return m_zoom;
 }
 
-QSize KReportItemMaps::size() const
-{
-    return m_size.toScene().toSize();
-}
-
 QString KReportItemMaps::themeId() const
 {
     return m_themeProperty->value().toString();
