@@ -27,15 +27,15 @@ class KReportWebPlugin : public KReportPluginInterface
     Q_OBJECT
 public:
     explicit KReportWebPlugin(QObject *parent, const QVariantList &args = QVariantList());
-    virtual ~KReportWebPlugin();
+    ~KReportWebPlugin() override;
 
-    virtual QObject *createRendererInstance(const QDomNode &element);
-    virtual QObject *createDesignerInstance(const QDomNode &element, KReportDesigner *designer,
-                                            QGraphicsScene *scene);
-    virtual QObject *createDesignerInstance(KReportDesigner *designer,
-                                            QGraphicsScene *scene,const QPointF &pos);
+    QObject *createRendererInstance(const QDomNode &element) override;
+    QObject *createDesignerInstance(const QDomNode &element, KReportDesigner *designer,
+                                            QGraphicsScene *scene) override;
+    QObject *createDesignerInstance(KReportDesigner *designer,
+                                            QGraphicsScene *scene,const QPointF &pos) override;
 #ifdef KREPORT_SCRIPTING
-    virtual QObject *createScriptInstance(KReportItemBase *item);
+    QObject *createScriptInstance(KReportItemBase *item) override;
 #endif
 };
 
